@@ -1,5 +1,5 @@
-from .core import cli
 from .hooks import post_reload, pre_reload
+from .run import cli
 from .utils import cache_across_reloads
 
 __all__ = ("cache_across_reloads", "cli", "post_reload", "pre_reload")
